#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.users.waitrose.com/~thunor/pipepanic/
# source           : http://www.users.waitrose.com/~thunor/pipepanic/dload/pipepanic-0.1.3-source.tar.gz

# Package name
NAME="pipepanic"
# Package version
VERSION="0.1.3"
# Source code URL
SOURCE="http://www.users.waitrose.com/~thunor/pipepanic/dload/pipepanic-$VERSION-source.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS Bugs COMPILING COPYING COPYING-ARTWORK ChangeLog README TODO VERSION"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Pipepanic is a pipe connecting game using libSDL
$NAME:
$NAME: Pipepanic is a pipe connecting game using libSDL that is playable
$NAME: on Linux PCs and the Sharp Zaurus. Connect as many different shaped 
$NAME: pipes together as possible within the time given.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Pipe panic
Exec=pipepanic
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=pipepanic
EOF

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION-source
if [ -f $NAME-$VERSION-source.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION-source.tar.gz

# Put icon in the right place
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cp $NAME-$VERSION-source/PipepanicIcon48.png $PKG/usr/share/icons/hicolor/48x48/apps/pipepanic.png

# no configure, just make, after a few changes
cd $NAME-$VERSION-source
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
sed -i -e 's/CFLAGS=-O2 -Wall -pedantic `sdl-config --cflags`/CFLAGS=-O2 -march=i486 -mtune=i686 -Wall -pedantic `sdl-config --cflags`/' Makefile
make

# Install on temporary directory
mkdir -p $PKG/usr/share/pipepanic
cp -a pipepanic *.xcf *.bmp *.png $PKG/usr/share/pipepanic

# Create a script to run the game
mkdir -p $PKG/usr/bin
cat > $PKG/usr/bin/pipepanic << EOF
# !/bin/bash

cd /usr/share/pipepanic
./pipepanic
EOF
chmod +x $PKG/usr/bin/pipepanic

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION-source
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION


# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION-source
rm -rf $PKG
